<?php
/**
 * An interface for I/O handlers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2014 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface IoHandler extends FileInputStreamer, FileOutputStreamer {
	/**
	 * Setter for the *real* file input instance
	 *
	 * @param	$inputStream	The *real* file-input class
	 * @return	void
	 */
	function setInputStream (FileInputStreamer $inputStream);

	/**
	 * Getter for the *real* file input instance
	 *
	 * @return	$inputStream	The *real* file-input class
	 */
	function getInputStream ();

	/**
	 * Setter for the *real* file output instance
	 *
	 * @param	$outputStream	The *real* file-output class
	 * @return	void
	 */
	function setOutputStream (FileOutputStreamer $outputStream);

	/**
	 * Getter for the *real* file output instance
	 *
	 * @return	$outputStream	The *real* file-output class
	 */
	function getOutputStream ();

	/**
	 * Saves a file with data by using the current output stream
	 *
	 * @param	$fileName			Name of the file
	 * @param	$dataStream			File data stream
	 * @param	$objectInstance		An instance of a FrameworkInterface class (default: NULL)
	 * @return	void
	 */
	function saveStreamToFile ($fileName, $dataStream, FrameworkInterface $objectInstance = NULL);
}

// [EOF]
?>
